@@ -1,10 +1,12 @@
-__all__ = ('get_function_environment_identifier',)
+__all__ = ('get_function_environment_identifier', 'shutdown_environments',)
 
+from scarletio import is_coroutine_function,is_coroutine_generator_function, is_generator_function
+
+from .configuration import ENVIRONMENTS_BY_SCOPE
 from .constants import (
     ENVIRONMENT_TYPE_COROUTINE, ENVIRONMENT_TYPE_COROUTINE_GENERATOR, ENVIRONMENT_TYPE_DEFAULT,
     ENVIRONMENT_TYPE_GENERATOR
 )
-from scarletio import is_coroutine_function,is_coroutine_generator_function, is_generator_function
 
 
 def get_function_environment_identifier(func):
@@ -30,3 +32,13 @@ def get_function_environment_identifier(func):
         return ENVIRONMENT_TYPE_GENERATOR
     
     return ENVIRONMENT_TYPE_DEFAULT
+
+
+def shutdown_environments():
+    """
+    Shuts down all the registered environments. This operation cannot be reverted.
+    """
+    for environment_by_detail in ENVIRONMENTS_BY_SCOPE.values():
+        for environments_by_identifier in environment_by_detail.values():
+            for environment in environments_by_identifier.values():
+                environment.shutdown()
