@@ -23,6 +23,7 @@ from .wrapper_call import *
 from .wrapper_chainer import *
 from .wrapper_conflict import *
 from .wrapper_environment import *
+from .wrapper_garbage_collect import *
 from .wrapper_revert import *
 from .wrapper_skip import *
 from .wrapper_skip_conditional import *
@@ -33,6 +34,7 @@ raising = WrapperCall.raising_constructor
 call_with = WrapperCall.call_with_constructor
 
 from .wrapper_environment import WrapperEnvironment as in_environment
+from .wrapper_garbage_collect import WrapperGarbageCollect as with_gc
 from .wrapper_revert import WrapperRevert as revert
 from .wrapper_skip import WrapperSkip as skip
 from .wrapper_skip_conditional import WrapperSkipConditional as skip_if
@@ -46,11 +48,14 @@ __all__ = (
     'revert',
     'skip',
     'skip_if',
+    'with_gc',
     
     *wrapper_base.__all__,
     *wrapper_call.__all__,
     *wrapper_chainer.__all__,
     *wrapper_conflict.__all__,
+    *wrapper_environment.__all__,
+    *wrapper_garbage_collect.__all__,
     *wrapper_revert.__all__,
     *wrapper_skip.__all__,
     *wrapper_skip_conditional.__all__,
